import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';
import '../../../support/step_definitions/doc_view_steps';

let tagset_id;
let doc_id;

Given('There is one favorite doc', () => {
  cy.appFactories([['create', 'doc_favorite', 'with_file', { user_id: '1' }]]).then(records => {
    tagset_id = records[0].tagset_id;
  });
});

Given('There is one doc', () => {
  cy.appFactories([['create', 'tagset_doc', 'with_file', 'with_state', { filename: 'pdf_sample.pdf', state_key: 'to_validate' }]]).then(records => {
    doc_id = records[0].doc_ids[0];
    tagset_id = records[0].id;
  });
});

Given('There is one wopi editable doc', () => {
  cy.appFactories([['create', 'tagset_doc', 'with_file', 'with_state', { filename: 'doc_sample.docx', state_key: 'to_validate' }]]).then(records => {
    doc_id = records[0].doc_ids[0];
    tagset_id = records[0].id;
  });
});

When('I click on the first doc', () => {
  cy.get('#model_table tbody tr:first td:last a:first').click();
});

When('I visit the doc page', () => {
  cy.visit(`/spirit_hub/tagsets/${tagset_id}/doc/${doc_id}`);
  cy.wait(1000); // TODO: remove when have a proper pdf viewer loading state
});

When('I validate the doc', () => {
  cy.get('form[action="/spirit_hub/tagsets/form/validate"] button').click();
  cy.get('textarea[name="message"]').type('This is a message');
  cy.get('select[name="recipients[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Admin User (admin@test.com)').first().click({ force: true });
  cy.get('button[data-base-form-target="submitButton"]').click({ force: true });
  cy.waitForTurboResponse();
});

Then('There is no more validation button', () => {
  cy.get('form[action="/spirit_hub/tagsets/form/validate"]').should('not.exist');
});

Then('I can toggle the button actions', () => {
  cy.get('button[title="Actions"]').click();
});

Then('I can click on the sent to button', () => {
  cy.get('button:visible').contains('Envoyer...').click();
});

When('I click on the share button', () => {
  cy.get('form[action*="/share"] button:visible').click();
});

Then('I can not edit with Office Online', () => {
  cy.contains('Éditer dans Office Online').should('not.exist');
});

Then('I can edit with Office Online', () => {
  cy.contains('Éditer dans Office Online').should('exist');
});

Then('The preview should be visible', () => {
  cy.get('canvas[data-pdf-viewer-target="content"]').should('be.visible');
});

When('Doc get a new file', () => {
  cy.appEval(`
    d = Doc.find('${doc_id}')
    d.store_file_from_disk(Rails.root.join('packages/spirit_hub/spec/fixtures/files/one_page.pdf'))
  `);
});

Then('The preview should have {string} pages', pages => {
  cy.get('[data-pdf-viewer-target="thumbnailContainer"]').find('.thumbnail').should('have.length', parseInt(pages));
});
